%define	debug_package		%{nil}
%define VirtualEnvironment      %{_prefix}/local/lib/PythonVirtualEnvironments/%{name}-%{version}

Name:           EVTXtract
Version:        0.2.3
Release:        1%{?dist}
Summary:        Recover and reconstruct fragments of EVTX log files from raw binary data

License:        Apache License 2.0
URL:            https://github.com/williballenthin/EVTXtract
Source0:        EVTXtract-0.2.4.tar.gz

%define lname %(echo %{name} | tr '[A-Z]' '[a-z]')
%global _description \
Python 2 and Python 3.

%description %{_description}

EVTX records are XML fragments encoded using a Microsoft-specific binary XML
representation. Despite the convenient format, it is not easy to recover EVTX event log records
from a corrupted file or unallocated space. This is because the complete representation of a
record often depends on other records found nearby. The event log service recognizes similarities
among records and refactors commonalities into "templates". A template is a fixed structure with
placeholders that reserve space for variable content. The on-disk event log record structure
is a reference to a template, and a list of substitutions (the variable content the replaces
a placeholder in a template). To decode a record into XML, the event log service resolves the
template and replaces its placeholders with the entries of the substitution array. Therefore,
template corruption renders many records unrecoverable within the local 64KB "chunk". However,
the substitution array for the remaining records may still be intact. If so, it may be
possible to produce XML fragments that match the original records if the damaged template can
be reconstructed. For many common events, such as process creation or account logon, empirical
testing demonstrates the relevant templates remain mostly constant. In these cases, recovering
event log records boils down to identifying appropriate templates found in other EVTX chunks.

Algorithm

 1. Scan for chunk signatures ("ElfChnk")
    a. check header for sane values (0x80 <= size <= 0x200)
    b. verify checksums (header, data)
 2. Extract records from valid chunks found in (1)
 3. Extract templates from valid chunks found in (1)
 4. Scan for record signatures
    a. check header for sane values
    a. extract timestamp
    c. attempt to parse substitutions
    d. attempt to decode substitutions into EID, other fields
 5. Reconstruct records by reusing old templates with recovered substitutions

%prep
echo Nothing to prep

%build
echo Nothing to build

%post
echo Building the Python Virtual Environment for %{name}. This will take a while. > /proc/$PPID/fd/1
mkdir -p %{VirtualEnvironment}
%if 0%{?fedora} >= 29
virtualenv --python=/usr/bin/python3 -q %{VirtualEnvironment}
%else
%if 0%{?centos} == 8 || 0%{?rhel} == 8
virtualenv-3 -q %{VirtualEnvironment}
%else
virtualenv -q %{VirtualEnvironment}
%endif
%endif
. %{VirtualEnvironment}/bin/activate
cp /dev/null /tmp/%{name}-%{version}-install.log
for p in pip %{name}
do
        echo -n Installing $p in the virtual environment ... > /proc/$PPID/fd/1
        pip install --upgrade "$p" >> /tmp/%{name}-%{version}-install.log 2>&1
        echo " Done" > /proc/$PPID/fd/1
done
echo Done building the Python Virtual Environment for %{name}. > /proc/$PPID/fd/1

%postun
rm -rf %{VirtualEnvironment}

%install
%__install -d %{buildroot}%{VirtualEnvironment}
%__install -d %{buildroot}%{_bindir}
for p in evtx_dump_chunk_slack.py evtx_dump.py evtx_eid_record_numbers.py evtx_extract_record.py \
	 evtx_filter_records.py evtx_info.py evtx_record_structure.py evtx_structure.py evtx_templates.py evtxtract 
do
	cat > %{buildroot}%{_bindir}/$p << EOF
#!/bin/sh
. %{VirtualEnvironment}/bin/activate
exec $p "\$@"
EOF
done

%clean
rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(644,root,root,755)
%attr(755, root, root)	%{_bindir}/*

%changelog
* Tue Oct  5 2021 Lawrence R. Rogers <lrr@cert.org> - 0.2.3-1
- Release 0.2.4-3
	Version 0.2.3, built as a virtual environment
